@@ -262,6 +262,7 @@ __all__ = (
     "UpdateMaintenanceWindowTargetResultTypeDef",
     "UpdateMaintenanceWindowTaskResultTypeDef",
     "UpdatePatchBaselineResultTypeDef",
+    "WaiterConfigTypeDef",
 )
 
 AccountSharingInfoTypeDef = TypedDict(
@@ -2831,3 +2832,7 @@ UpdatePatchBaselineResultTypeDef = TypedDict(
     },
     total=False,
 )
+
+WaiterConfigTypeDef = TypedDict(
+    "WaiterConfigTypeDef", {"Delay": int, "MaxAttempts": int}, total=False
+)
